from typing import List

from pydantic import BaseModel


class Image(BaseModel):
    title: str
    url: str


class Edition(BaseModel):
    title: str
    description: str
    type: int
    publisher_id: int
    texts: list
    images: List[Image]
    youtube_videos: list



from pydantic import BaseModel

from .book import Book


class Task(BaseModel):
    title: str
    title_short: str
    description: str
    youtube_video_id: str
    url: str


class ExtendedTask(BaseModel):
    success: bool
    message: str
    paths: dict
    book: Book
    task: Task
    editions: list



from typing import List

from pydantic import BaseModel


class Cover(BaseModel):
    title: str
    url: str


class Price(BaseModel):
    purchase: int
    download: int


class Book(BaseModel):
    id: int
    parent_id: int
    country: str
    subject_id: int
    title: str
    header: str
    breadcrumb: str
    year: str
    classes: List[int]
    authors: List[str]
    authors_ru: List[str]
    authors_en: List[str]
    authors_by: List[str]
    authors_ua: List[str]
    description: str
    publisher: str
    category: str
    series: str
    subtype: str
    study_level: str
    parts: list
    cover: Cover
    cover_url: str
    search_keywords: str
    price: Price
    tasks_view: str
    is_paid: bool
    url: str
    priority: int
    updated_at: int




from typing import List

import requests

from .types.book import Book
from .types.class_ import Class
from .types.structure_entry import StructureEntry
from .types.subject import Subject
from .types.task import Task, ExtendedTask


class GDZ:
    API_ENDPOINT = "https://gdz-ru.com"

    def __init__(self):
        self.session = requests.Session()
        self.main_info = requests.get(self.API_ENDPOINT).json()

    @property
    def classes(self) -> List[Class]:
        return [Class(**external_data) for external_data in self.main_info["classes"]]

    @property
    def subjects(self) -> List[Subject]:
        return [
            Subject(**external_data) for external_data in self.main_info["subjects"]
        ]

    @property
    def books(self) -> List[Book]:
        return [Book(**external_data) for external_data in self.main_info["books"]]

    def book_structure(self, book: Book) -> List[StructureEntry]:
        structure = requests.get(self.API_ENDPOINT + book.url).json()["structure"]
        return [StructureEntry(**external_data) for external_data in structure]

    def task_extended(self, task: Task) -> ExtendedTask:
        task_info = requests.get(self.API_ENDPOINT + task.url).json()
        return ExtendedTask(**task_info)



from typing import List

from pydantic import BaseModel

from gdz.types.task import Task


class StructureEntry(BaseModel):
    title: str
    title_short: str
    description: str
    tasks: List[Task]
    topics: list
